Source-Changes-HG archive
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]
[src/nathanw_sa]: src/sys/arch LWPify
details: https://anonhg.NetBSD.org/src/rev/ee314f0c38f0
branches: nathanw_sa
changeset: 506273:ee314f0c38f0
user: gmcgarry <gmcgarry%NetBSD.org@localhost>
date: Sat Oct 05 01:17:23 2002 +0000
description:
LWPify
diffstat:
sys/arch/arc/arc/machdep.c | 10 +++++-----
sys/arch/arc/jazz/asc.c | 4 ++--
sys/arch/mips/mips/locore_mips3.S | 4 ++--
3 files changed, 9 insertions(+), 9 deletions(-)
diffs (67 lines):
diff -r a464796b9eed -r ee314f0c38f0 sys/arch/arc/arc/machdep.c
--- a/sys/arch/arc/arc/machdep.c Sat Oct 05 01:13:57 2002 +0000
+++ b/sys/arch/arc/arc/machdep.c Sat Oct 05 01:17:23 2002 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: machdep.c,v 1.64.2.6 2002/09/17 21:13:12 nathanw Exp $ */
+/* $NetBSD: machdep.c,v 1.64.2.7 2002/10/05 01:17:23 gmcgarry Exp $ */
/* $OpenBSD: machdep.c,v 1.36 1999/05/22 21:22:19 weingart Exp $ */
/*
@@ -428,9 +428,9 @@
* Allocate space for proc0's USPACE.
*/
v = (caddr_t)uvm_pageboot_alloc(USPACE);
- proc0.p_addr = proc0paddr = (struct user *)v;
- proc0.p_md.md_regs = (struct frame *)(v + USPACE) - 1;
- curpcb = &proc0.p_addr->u_pcb;
+ lwp0.l_addr = proc0paddr = (struct user *)v;
+ lwp0.l_md.md_regs = (struct frame *)(v + USPACE) - 1;
+ curpcb = &lwp0.l_addr->u_pcb;
curpcb->pcb_context[11] = MIPS_INT_MASK | MIPS_SR_INT_IE; /* SR */
/*
@@ -615,7 +615,7 @@
if ((howto & RB_NOSYNC) == 0 && waittime < 0) {
/* fill curlwp with live object */
if (curlwp == NULL)
- curlwp = &proc0;
+ curlwp = &lwp0;
/*
* Synchronize the disks....
*/
diff -r a464796b9eed -r ee314f0c38f0 sys/arch/arc/jazz/asc.c
--- a/sys/arch/arc/jazz/asc.c Sat Oct 05 01:13:57 2002 +0000
+++ b/sys/arch/arc/jazz/asc.c Sat Oct 05 01:17:23 2002 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: asc.c,v 1.6.2.2 2002/06/24 22:03:43 nathanw Exp $ */
+/* $NetBSD: asc.c,v 1.6.2.3 2002/10/05 01:19:15 gmcgarry Exp $ */
/* $OpenBSD: asc.c,v 1.9 1998/03/16 09:38:39 pefo Exp $ */
/* NetBSD: asc.c,v 1.10 1994/12/05 19:11:12 dean Exp */
@@ -682,7 +682,7 @@
* mapped to UADDR. Realloc to the kva uarea address.
*/
if((u_int)(xs->data) >= UADDR) {
- xs->data = ((u_int)(xs->data) & ~UADDR) + (u_char *)(curlwp->p_addr);
+ xs->data = ((u_int)(xs->data) & ~UADDR) + (u_char *)(curlwp->l_addr);
}
s = splbio();
diff -r a464796b9eed -r ee314f0c38f0 sys/arch/mips/mips/locore_mips3.S
--- a/sys/arch/mips/mips/locore_mips3.S Sat Oct 05 01:13:57 2002 +0000
+++ b/sys/arch/mips/mips/locore_mips3.S Sat Oct 05 01:17:23 2002 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: locore_mips3.S,v 1.72.2.9 2002/09/17 21:15:47 nathanw Exp $ */
+/* $NetBSD: locore_mips3.S,v 1.72.2.10 2002/10/05 01:21:09 gmcgarry Exp $ */
/*
* Copyright (c) 1997 Jonathan Stone (hereinafter referred to as the author)
@@ -176,7 +176,7 @@
* the QED RM52xx family of CPUs, and MIPS32 & MIPS64 CPUs.
*/
LEAF(mips_wait_idle)
- sw zero, _C_LABEL(curproc) # set curproc NULL for stats
+ sw zero, _C_LABEL(curlwp) # set curlwp NULL for stats
#if defined(LOCKDEBUG)
jal _C_LABEL(sched_unlock_idle) # release sched_lock
nop
Home |
Main Index |
Thread Index |
Old Index